[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] Replace Xen_regs with cpu_users_regs to match upstream



# HG changeset patch
# User fred@xxxxxxxxxxxxxxxxxxxxx
# Node ID a6bb479191613810dd22974219198f24e0935c4e
# Parent  c56a9805216a23c014d91d213a7a0962566b76fc
Replace Xen_regs with cpu_users_regs to match upstream

diff -r c56a9805216a -r a6bb47919161 xen/arch/ia64/Rules.mk
--- a/xen/arch/ia64/Rules.mk    Tue Aug  9 10:32:52 2005
+++ b/xen/arch/ia64/Rules.mk    Fri Aug 12 23:08:58 2005
@@ -22,7 +22,7 @@
            -I$(BASEDIR)/include/asm-ia64/linux-xen                     \
            -I$(BASEDIR)/arch/ia64/linux -I$(BASEDIR)/arch/ia64/linux-xen
 CFLAGS  += -Wno-pointer-arith -Wredundant-decls
-CFLAGS  += -DIA64 -DXEN -DLINUX_2_6 -DXEN_HYPERVISOR
+CFLAGS  += -DIA64 -DXEN -DLINUX_2_6
 CFLAGS += -ffixed-r13 -mfixed-range=f12-f15,f32-f127
 CFLAGS += -w -g
 ifeq ($(CONFIG_VTI),y)
diff -r c56a9805216a -r a6bb47919161 xen/arch/ia64/asm-offsets.c
--- a/xen/arch/ia64/asm-offsets.c       Tue Aug  9 10:32:52 2005
+++ b/xen/arch/ia64/asm-offsets.c       Fri Aug 12 23:08:58 2005
@@ -139,14 +139,14 @@
        DEFINE(IA64_PT_REGS_R2_OFFSET, offsetof (struct pt_regs, r2));
        DEFINE(IA64_PT_REGS_R3_OFFSET, offsetof (struct pt_regs, r3));
 #ifdef CONFIG_VTI
-       DEFINE(IA64_PT_REGS_R4_OFFSET, offsetof (struct xen_regs, r4));
-       DEFINE(IA64_PT_REGS_R5_OFFSET, offsetof (struct xen_regs, r5));
-       DEFINE(IA64_PT_REGS_R6_OFFSET, offsetof (struct xen_regs, r6));
-       DEFINE(IA64_PT_REGS_R7_OFFSET, offsetof (struct xen_regs, r7));
-       DEFINE(IA64_PT_REGS_CR_IIPA_OFFSET, offsetof (struct xen_regs, 
cr_iipa));
-       DEFINE(IA64_PT_REGS_CR_ISR_OFFSET, offsetof (struct xen_regs, cr_isr));
-       DEFINE(IA64_PT_REGS_EML_UNAT_OFFSET, offsetof (struct xen_regs, 
eml_unat));
-       DEFINE(IA64_PT_REGS_RFI_PFS_OFFSET, offsetof (struct xen_regs, 
rfi_pfs));
+       DEFINE(IA64_PT_REGS_R4_OFFSET, offsetof (struct pt_regs, r4));
+       DEFINE(IA64_PT_REGS_R5_OFFSET, offsetof (struct pt_regs, r5));
+       DEFINE(IA64_PT_REGS_R6_OFFSET, offsetof (struct pt_regs, r6));
+       DEFINE(IA64_PT_REGS_R7_OFFSET, offsetof (struct pt_regs, r7));
+       DEFINE(IA64_PT_REGS_CR_IIPA_OFFSET, offsetof (struct pt_regs, cr_iipa));
+       DEFINE(IA64_PT_REGS_CR_ISR_OFFSET, offsetof (struct pt_regs, cr_isr));
+       DEFINE(IA64_PT_REGS_EML_UNAT_OFFSET, offsetof (struct pt_regs, 
eml_unat));
+       DEFINE(IA64_PT_REGS_RFI_PFS_OFFSET, offsetof (struct pt_regs, rfi_pfs));
        DEFINE(RFI_IIP_OFFSET, offsetof(struct vcpu, arch.arch_vmx.rfi_iip));
        DEFINE(RFI_IPSR_OFFSET, offsetof(struct vcpu, arch.arch_vmx.rfi_ipsr));
        DEFINE(RFI_IFS_OFFSET,offsetof(struct vcpu ,arch.arch_vmx.rfi_ifs));
diff -r c56a9805216a -r a6bb47919161 xen/arch/ia64/domain.c
--- a/xen/arch/ia64/domain.c    Tue Aug  9 10:32:52 2005
+++ b/xen/arch/ia64/domain.c    Fri Aug 12 23:08:58 2005
@@ -450,7 +450,7 @@
                 unsigned long start_info)
 {
        struct domain *d = v->domain;
-       struct xen_regs *regs;
+       struct pt_regs *regs;
        struct ia64_boot_param *bp;
        extern char saved_command_line[];
        //char *dom0_cmdline = "BOOT_IMAGE=scsi0:\EFI\redhat\xenlinux nomca 
root=/dev/sdb1 ro";
diff -r c56a9805216a -r a6bb47919161 xen/include/asm-ia64/linux-xen/asm/ptrace.h
--- a/xen/include/asm-ia64/linux-xen/asm/ptrace.h       Tue Aug  9 10:32:52 2005
+++ b/xen/include/asm-ia64/linux-xen/asm/ptrace.h       Fri Aug 12 23:08:58 2005
@@ -97,6 +97,7 @@
  */
 #ifdef XEN
 #include <public/arch-ia64.h>
+#define pt_regs cpu_user_regs
 #else
 struct pt_regs {
        /* The following registers are saved by SAVE_MIN: */
diff -r c56a9805216a -r a6bb47919161 xen/include/asm-ia64/regs.h
--- a/xen/include/asm-ia64/regs.h       Tue Aug  9 10:32:52 2005
+++ b/xen/include/asm-ia64/regs.h       Fri Aug 12 23:08:58 2005
@@ -1,3 +1,2 @@
 #include <asm/ptrace.h>
-#define cpu_user_regs pt_regs
 #define xen_regs pt_regs
diff -r c56a9805216a -r a6bb47919161 xen/include/asm-ia64/vcpu.h
--- a/xen/include/asm-ia64/vcpu.h       Tue Aug  9 10:32:52 2005
+++ b/xen/include/asm-ia64/vcpu.h       Fri Aug 12 23:08:58 2005
@@ -6,6 +6,7 @@
 
 //#include "thread.h"
 #include <asm/ia64_int.h>
+#include <public/arch-ia64.h>
 
 typedef        unsigned long UINT64;
 typedef        unsigned int UINT;
@@ -13,7 +14,7 @@
 struct vcpu;
 typedef        struct vcpu VCPU;
 
-typedef struct pt_regs REGS;
+typedef cpu_user_regs_t REGS;
 
 #define VCPU(_v,_x)    _v->vcpu_info->arch.privregs->_x
 
diff -r c56a9805216a -r a6bb47919161 xen/include/public/arch-ia64.h
--- a/xen/include/public/arch-ia64.h    Tue Aug  9 10:32:52 2005
+++ b/xen/include/public/arch-ia64.h    Fri Aug 12 23:08:58 2005
@@ -57,11 +57,7 @@
         } u;
 };
 
-#ifdef XEN_HYPERVISOR
-struct pt_regs {
-#else
-struct xen_pt_regs {
-#endif
+typedef struct cpu_user_regs{
        /* The following registers are saved by SAVE_MIN: */
        unsigned long b6;               /* scratch */
        unsigned long b7;               /* scratch */
@@ -142,7 +138,7 @@
        struct pt_fpreg f9;             /* scratch */
        struct pt_fpreg f10;            /* scratch */
        struct pt_fpreg f11;            /* scratch */
-};
+}cpu_user_regs_t;
 
 typedef union {
        unsigned long value;
@@ -278,11 +274,7 @@
        unsigned long vm_assist;   /* VMASST_TYPE_* bitmap, now none on IPF */
        unsigned long guest_iip;   /* Guest entry point */
 
-#ifdef XEN_HYPERVISOR
-       struct pt_regs regs;
-#else
-       struct xen_pt_regs regs;
-#endif
+       cpu_user_regs_t regs;
        arch_vcpu_info_t vcpu;
        arch_shared_info_t shared;
 } vcpu_guest_context_t;

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.
diff -r c56a9805216a -r a6bb47919161 xen/arch/ia64/vmx_vcpu.c
--- a/xen/arch/ia64/vmx_vcpu.c  Tue Aug  9 10:32:52 2005
+++ b/xen/arch/ia64/vmx_vcpu.c  Fri Aug 12 23:08:58 2005
@@ -111,7 +111,7 @@
     }
     new_psr.val=vmx_vcpu_get_psr(vcpu);
     {
-    struct xen_regs *regs = vcpu_regs(vcpu);
+    struct pt_regs *regs = vcpu_regs(vcpu);
     guest_psr_buf[guest_psr_index].ip = regs->cr_iip;
     guest_psr_buf[guest_psr_index].psr = new_psr.val;
     if (++guest_psr_index >= 100)
@@ -141,7 +141,7 @@
     return IA64_NO_FAULT;
 }
 
 /* Adjust slot both in xen_regs and vpd, upon vpsr.ri which
  * should have sync with ipsr in entry.
  *
  * Clear some bits due to successfully emulation.
@@ -141,7 +141,7 @@
 }
 
-/* Adjust slot both in xen_regs and vpd, upon vpsr.ri which
+/* Adjust slot both in pt_regs and vpd, upon vpsr.ri which
  * should have sync with ipsr in entry.
  *